//
//  vecmathオブジェクトを引数としてOpenGL関数を呼び出すための補助関数
//

/**
***  @file  vecmath_gl.h
***  @brief vecmathオブジェクトを引数としてOpenGL関数を呼び出すための補助関数
**/


#ifndef  _VECMATH_GL_H_
#define  _VECMATH_GL_H_


#include <Vector3.h>
#include <Point3.h>
#include <Point2.h>
#include <Color3.h>
#include <Matrix3.h>
#include <Matrix4.h>


inline void  glVertex3f( const Tuple3f & v )
{
	glVertex3f( v.x, v.y, v.z );
}

inline void  glTexCoord2f( const Tuple2f & t )
{
	glTexCoord2f( t.x, t.y );
}

inline void  glNormal3f( const Vector3f & n )
{
	glNormal3f( n.x, n.y, n.z );
}

inline void  glColor3f( const Color3f & c )
{
	glColor3f( c.x, c.y, c.z );
}

inline void  glColor4f( const Color4f & c )
{
	glColor4f( c.x, c.y, c.z, c.w );
}


inline void  glTranslatef( const Tuple3f & t )
{
	glTranslatef( t.x, t.y, t.z );
}

inline void  glMultMatrixf( const Matrix4f & m )
{
	Matrix4f  mat;
	mat.transpose( m );
	glMultMatrixf( &mat.m00 );
}

inline void  glMultMatrixf( const Matrix3f & m )
{
	Matrix4f  mat;
	mat.set( m );
	mat.transpose();
	glMultMatrixf( &mat.m00 );
}


#endif // _VECMATH_GL_H_
